searchNodes=[{"doc":"Extract data from nested Elixir data structure using JSONPath-like path expressions. See this page for syntax. Examples # string iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , ~S/.&quot;b&quot;/ ) { :ok , [ 2 ] } # you can use Elixpath.get! if you want only a single match iex&gt; Elixpath . get! ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.*&quot; ) 1 # unquoted string iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.b&quot; ) { :ok , [ 2 ] } # no match iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.nonsense&quot; ) { :ok , [ ] } # no match w/ get! iex&gt; Elixpath . get! ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.nonsense&quot; , _default = :some_default_value ) :some_default_value # atom iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.:a&quot; ) { :ok , [ 1 ] } # integer iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;.:a[-1]&quot; ) { :ok , [ %{ c : 3 } ] } # descendant iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;..:c&quot; ) { :ok , [ 3 ] } # wildcard iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;.*.*.*&quot; ) { :ok , [ 2 , 3 ] } # enable sigil_p/2, which parses Elixpath at compile time. iex&gt; import Elixpath iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , ~p&quot;.:a.1.:c&quot; ) { :ok , [ 3 ] } # path syntax error for normal string is detected at runtime. iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;.:atom:syntax:error&quot; ) { :error , &quot;expected member_expression while processing path&quot; } # while sigil_p raises a compilation error: # iex&gt; Elixpath.query(%{:a =&gt; [%{b: 2}, %{c: 3}]}, ~p&quot;.:atom:syntax:error&quot;) # == Compilation error in file test/elixpath_test.exs == # ** (Elixpath.Parser.ParseError) ...","ref":"Elixpath.html","title":"Elixpath","type":"module"},{"doc":"Get single data from nested data structure. Returns default when no match. Raises on error.","ref":"Elixpath.html#get!/4","title":"Elixpath.get!/4","type":"function"},{"doc":"Query data from nested data structure. Returns list of matches, wrapped by :ok . When no match, {:ok, []} is returned. Options For path parsing options, see Elixpath.Parser.parse/2 .","ref":"Elixpath.html#query/3","title":"Elixpath.query/3","type":"function"},{"doc":"Query data from nested data structure. Same as query/3 , except that query!/3 raises on error. Returns [] when no match.","ref":"Elixpath.html#query!/3","title":"Elixpath.query!/3","type":"function"},{"doc":"Compiles string to internal Elixpath representation. Warning: Do not specify unsafe_atom modifier ( u ) for untrusted input. See String.to_atom/1 , which this function uses to create new atom, for details. Modifiers unsafe_atom (u) - passes unsafe_atom: true option to Elixpath.Parser.parse/2 . atom_keys_preferred (a) - passes prefer_keys: :atom option to Elixpath.Parser.parse/2 . Examples iex&gt; import Elixpath , only : [ sigil_p : 2 ] iex&gt; ~p/.string..:b[1]/ # Elixpath &lt; [ elixpath_child : &quot;string&quot; , elixpath_descendant : :b , elixpath_child : 1 ] &gt; iex&gt; ~p/.atom..:b[1]/a # Elixpath &lt; [ elixpath_child : :atom , elixpath_descendant : :b , elixpath_child : 1 ] &gt;","ref":"Elixpath.html#sigil_p/2","title":"Elixpath.sigil_p/2","type":"macro"},{"doc":"Converts Elixpath to string. Also available via Kernel.to_string/1 . This function is named stringify/1 to avoid name collision with Kernel.to_string/1 when the entire module is imported. Examples iex&gt; import Elixpath , only : [ sigil_p : 2 ] iex&gt; path = ~p/.1.child..:decendant/u # Elixpath &lt; [ elixpath_child : 1 , elixpath_child : &quot;child&quot; , elixpath_descendant : :decendant ] &gt; iex&gt; path |&gt; to_string ( ) &quot;[1]. \\&quot; child \\&quot; ..:decendant&quot; iex&gt; &quot;interpolation: \#{ ~p/..1[*]..*/ } &quot; &quot;interpolation: ..[1].*..*&quot;","ref":"Elixpath.html#stringify/1","title":"Elixpath.stringify/1","type":"function"},{"doc":"Elixpath, already compiled by Elixpath.Parser.parse/2 or sigil_p/2 .","ref":"Elixpath.html#t:t/0","title":"Elixpath.t/0","type":"type"},{"doc":"Used for querying each data type.","ref":"Elixpath.Access.html","title":"Elixpath.Access","type":"protocol"},{"doc":"Fetches all children that matches key from data . key can be Elixpath.Tag.wildcard() (i.e. :elixpath_wildcard ), which stands for &quot;all the children&quot;","ref":"Elixpath.Access.html#query/3","title":"Elixpath.Access.query/3","type":"function"},{"doc":"","ref":"Elixpath.Access.html#t:t/0","title":"Elixpath.Access.t/0","type":"type"},{"doc":"Parses Elixpath expressions.","ref":"Elixpath.Parser.html","title":"Elixpath.Parser","type":"module"},{"doc":"Parses an Elixpath expression. See this page for syntax. Warning: when unsafe_atom: true is specified, this function creates new atom using String.to_atom/1 . Do not specify unsafe_atom: true for untrusted input. See String.to_atom/1 for details. Options :unsafe_atom - if true , allows to create non-existing atoms, defaults to false . :prefer_keys - unquoted keys are converted to string ( :string ) or atom ( :atom ). Defaults to :string .","ref":"Elixpath.Parser.html#parse/2","title":"Elixpath.Parser.parse/2","type":"function"},{"doc":"Parses an Elixpath expression. Raises on error. See parse/2 for available options.","ref":"Elixpath.Parser.html#parse!/2","title":"Elixpath.Parser.parse!/2","type":"function"},{"doc":"","ref":"Elixpath.Parser.html#t:option/0","title":"Elixpath.Parser.option/0","type":"type"},{"doc":"Path components to form an Elixpath. Defined as macros for use in guards and pattern matching.","ref":"Elixpath.PathComponent.html","title":"Elixpath.PathComponent","type":"module"},{"doc":"Child path component, e.g. Map/Keyword value or list element.","ref":"Elixpath.PathComponent.html#child/1","title":"Elixpath.PathComponent.child/1","type":"macro"},{"doc":"Descendant path component, recursively including children, grand-children, and so on.","ref":"Elixpath.PathComponent.html#descendant/1","title":"Elixpath.PathComponent.descendant/1","type":"macro"},{"doc":"","ref":"Elixpath.PathComponent.html#t:child/0","title":"Elixpath.PathComponent.child/0","type":"type"},{"doc":"","ref":"Elixpath.PathComponent.html#t:descendant/0","title":"Elixpath.PathComponent.descendant/0","type":"type"},{"doc":"","ref":"Elixpath.PathComponent.html#t:key/0","title":"Elixpath.PathComponent.key/0","type":"type"},{"doc":"","ref":"Elixpath.PathComponent.html#t:t/0","title":"Elixpath.PathComponent.t/0","type":"type"},{"doc":"Constants used to represent each path component. Defined as macros for use in guards and pattern matching.","ref":"Elixpath.Tag.html","title":"Elixpath.Tag","type":"module"},{"doc":"","ref":"Elixpath.Tag.html#child/0","title":"Elixpath.Tag.child/0","type":"macro"},{"doc":"","ref":"Elixpath.Tag.html#descendant/0","title":"Elixpath.Tag.descendant/0","type":"macro"},{"doc":"Used in combination with child/0 or descendant/0 , e.g. Elixpath.PathComponent.child(Elixpath.Tag.wildcard()) represents &quot;all the children.&quot;","ref":"Elixpath.Tag.html#wildcard/0","title":"Elixpath.Tag.wildcard/0","type":"macro"},{"doc":"","ref":"Elixpath.Tag.html#t:child/0","title":"Elixpath.Tag.child/0","type":"type"},{"doc":"","ref":"Elixpath.Tag.html#t:descendant/0","title":"Elixpath.Tag.descendant/0","type":"type"},{"doc":"","ref":"Elixpath.Tag.html#t:wildcard/0","title":"Elixpath.Tag.wildcard/0","type":"type"},{"doc":"Syntax error while parsing an Elixpath string.","ref":"Elixpath.Parser.ParseError.html","title":"Elixpath.Parser.ParseError","type":"exception"},{"doc":"Elixpath Extract data from Elixir's native data structure using JSONPath-like path expressions.","ref":"readme.html","title":"Elixpath","type":"extras"},{"doc":"If you are planning to manipulate XML documents directly, other packages like sweet_xml can be better choices.","ref":"readme.html#searching-for-xpath-tools","title":"Elixpath - Searching for XPath Tools?","type":"extras"},{"doc":"Elixpath's path expression is based on JSONPath , but mainly with following differences: Following Elixir's native expressions are supported: String, e.g. ..string.&quot;double-quoted string&quot; Atom, e.g. .:atom.:&quot;quoted atom&quot; Charlist, e.g. .'single-quoted' Integer, e.g. [1][-1] Several JSONPath features like following are not supported: &quot;Current object&quot; syntax element: @ Union subscript operator: [xxx,yyy] Array slice operator: [start:end:stop] Filter and script expression using ()","ref":"readme.html#elixpath-expression","title":"Elixpath - Elixpath Expression","type":"extras"},{"doc":"An Elixpath is represented by a sequence of following path components. $ - root object. Optional. When present, this component has to be at the beginning of the path. .(key expression) or [(key expression)] - child objects that matches the given key. ..(key expression) - descendant objects that matches the given key. (key expression) above can be either of: integer - used to specify index in lists. Value can be negative, e.g. -1 represents the last element. atom - starts with colon and can be quoted, e.g. :atom , :&quot;quoted_atom&quot; . When prefer_keys: :atom option is given, preceding colon can be omitted. string - double-quoted. Double quotation can be omitted unless prefer_keys: :atom option is given. charlist - single-quoted. wildcard - * . Represents all the children.","ref":"readme.html#path-syntax","title":"Elixpath - Path Syntax","type":"extras"},{"doc":"# string iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , ~S/.&quot;b&quot;/ ) { :ok , [ 2 ] } # you can use Elixpath.get! if you want only a single match iex&gt; Elixpath . get! ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.*&quot; ) 1 # unquoted string iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.b&quot; ) { :ok , [ 2 ] } # no match iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.nonsense&quot; ) { :ok , [ ] } # no match w/ get! iex&gt; Elixpath . get! ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.nonsense&quot; , _default = :some_default_value ) :some_default_value # atom iex&gt; Elixpath . query ( %{ :a = &gt; 1 , &quot;b&quot; = &gt; 2 } , &quot;.:a&quot; ) { :ok , [ 1 ] } # integer iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;.:a[-1]&quot; ) { :ok , [ %{ c : 3 } ] } # descendant iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;..:c&quot; ) { :ok , [ 3 ] } # wildcard iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;.*.*.*&quot; ) { :ok , [ 2 , 3 ] } # enable sigil_p/2, which parses Elixpath at compile time. iex&gt; import Elixpath iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , ~p&quot;.:a.1.:c&quot; ) { :ok , [ 3 ] } # path syntax error for normal string is detected at runtime. iex&gt; Elixpath . query ( %{ :a = &gt; [ %{ b : 2 } , %{ c : 3 } ] } , &quot;.:atom:syntax:error&quot; ) { :error , &quot;expected member_expression while processing path&quot; } # while sigil_p raises a compilation error: # iex&gt; Elixpath.query(%{:a =&gt; [%{b: 2}, %{c: 3}]}, ~p&quot;.:atom:syntax:error&quot;) # == Compilation error in file test/elixpath_test.exs == # ** (Elixpath.Parser.ParseError) ...","ref":"readme.html#examples","title":"Elixpath - Examples","type":"extras"}]